@@ -1,6 +1,6 @@
 """Check exceeding negations in boolean expressions trigger warnings"""
 
-# pylint: disable=singleton-comparison, too-many-branches
+# pylint: disable=singleton-comparison, too-many-branches, too-few-public-methods
 
 def unneeded_not():
     """This is not ok
@@ -49,3 +49,9 @@ def not_checked():
         pass
     if not 2 <= someint < 3 < 4:
         pass
+
+class Klass(object):
+    """This is also ok"""
+    def __ne__(self, other):
+        return not self == other
+
